==> trinion_backend-1.0.0.tar.gz: trinion_backend/js/custom.js <==
(function ($, Drupal) {
  Drupal.behaviors.custom = {
    attach: function (context, settings) {
      $(document).keydown(function(e) {
        var keyCode = e.keyCode;
        if (keyCode == 115 && $("#modal-fast-task").length > 0) {
          $("#modal-fast-task").modal("show");
        }
      });

      $(".node-attache-file").click(function(e){
        e.preventDefault();
        if ($("#trinion-crm-file-upload #edit-file").length)
          $("#trinion-crm-file-upload #edit-file").click();
        if ($("#trinion-zadachnik-file-upload #edit-file").length)
          $("#trinion-zadachnik-file-upload #edit-file").click();
      });
      $(".replay-comment").click(function(){
        var textarea = $("textarea[data-drupal-selector='edit-field-tz-kommentariy-0-value']");
        textarea.val(textarea.val() + '#' + $(this).data('cid') + "\n");
        document.getElementById('edit-field-tz-kommentariy-0-value').scrollIntoView();
        textarea.focus();
      });
      $(".task-comment-attach").click(function(){
        console.log($("#comment-form .form-file").length)
        $("#comment-form .form-file").click();
      });
      once('trinion-custom', 'body', context).forEach(function (element) {
        var menu_state = localStorage.getItem('left_menu_hide');
        if (menu_state == 'true')
          $("aside.navbar").addClass("minified-menu");
        $(".navbar .navbar-toggle").click(function (e) {
          e.preventDefault();
          $("aside.navbar").toggleClass("minified-menu");
          var menu_state = localStorage.getItem('left_menu_hide');
          localStorage.setItem('left_menu_hide', menu_state == 'false' ? 'true' : 'false' );
        });
        $(".document-list .views-row").click(function(){
          var id = $(this).data('nid');
          Drupal.ajax({url: `/view-document-callback/${id}`}).execute();
          history.pushState(null, '', `/node/${id}`);
          $(".document-list .views-row").removeClass('selected');
          $(this).addClass('selected');
        });
        $(".launch.icon.item").click(function(){
          $("#left-menu").toggle();
        });
        var player = new Plyr('#lesson-player');
      });
    }
  };
})(jQuery, Drupal);

==> trinion_backend-1.0.1.tar.gz: trinion_backend/js/custom.js <==
(function ($, Drupal) {
  Drupal.behaviors.custom = {
    attach: function (context, settings) {
      $("#edit-field-tz-proekt").mousedown(function(){
        $("#edit-field-tz-kategoriya-zadachi").val("_none");
      });
      $("#edit-field-tp-schet-dlya-0-target-id").on("autocompleteopen", function(){
        $("[data-drupal-selector='edit-field-tl-contact']").val("_none");
      });
      if ($('#show-filter').length) {
        if ($($('#show-filter').data('bs-target')).length == 0)
          $('#show-filter').hide();
      }
      $(document).keydown(function(e) {
        var keyCode = e.keyCode;
        if (keyCode == 115 && $("#modal-fast-task").length > 0) {
          $("#modal-fast-task").modal("show");
        }
      });

      $(".node-attache-file").click(function(e){
        e.preventDefault();
        if ($("#trinion-crm-file-upload #edit-file").length)
          $("#trinion-crm-file-upload #edit-file").click();
        if ($("#trinion-zadachnik-file-upload #edit-file").length)
          $("#trinion-zadachnik-file-upload #edit-file").click();
      });
      $(".replay-comment").click(function(){
        var textarea = $("textarea[data-drupal-selector='edit-field-tz-kommentariy-0-value']");
        textarea.val(textarea.val() + '#' + $(this).data('cid') + "\n");
        document.getElementById('edit-field-tz-kommentariy-0-value').scrollIntoView();
        textarea.focus();
      });
      $(".task-comment-attach").click(function(){
        $("#comment-form .form-file").click();
      });
      once('trinion-custom', 'body', context).forEach(function (element) {
        var menu_state = localStorage.getItem('left_menu_hide');
        if (menu_state == 'true') {
          $("aside.navbar").addClass("minified-menu");
          $("body").addClass("menu-collapsed");
        }
        $(".navbar .navbar-toggle").click(function (e) {
          e.preventDefault();
          $("aside.navbar").toggleClass("minified-menu");
          $("body").toggleClass("menu-collapsed");
          var menu_state = localStorage.getItem('left_menu_hide');
          localStorage.setItem('left_menu_hide', menu_state == 'false' ? 'true' : 'false' );
        });
        $(".document-list .views-row").click(function(){
          var id = $(this).data('nid');
          Drupal.ajax({url: `/view-document-callback/${id}`}).execute();
          history.pushState(null, '', `/node/${id}`);
          $(".document-list .views-row").removeClass('selected');
          $(this).addClass('selected');
        });
        $(".launch.icon.item").click(function(){
          $("#left-menu").toggle();
        });
        if ($('#lesson-player').length > 0)
          var player = new Plyr('#lesson-player');
      });
      $(".my-all-switcher").change(function(){
        var list = $(this).data('list');
        var val = $(this).prop("checked");
        Drupal.ajax({url: `/my-all-switcher/${list}/${val}`}).execute().done(function(){
          $(".views-exposed-form .form-submit").click();
        });
      });
    }
  };
})(jQuery, Drupal);
